/****************************************************************************
** Meta object code from reading C++ file 'repositorywrapper.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../syntax-highlighting-5.116.0/src/quick/repositorywrapper.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QVector>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'repositorywrapper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_RepositoryWrapper_t {
    QByteArrayData data[23];
    char stringdata0[373];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_RepositoryWrapper_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_RepositoryWrapper_t qt_meta_stringdata_RepositoryWrapper = {
    {
QT_MOC_LITERAL(0, 0, 17), // "RepositoryWrapper"
QT_MOC_LITERAL(1, 18, 17), // "definitionForName"
QT_MOC_LITERAL(2, 36, 31), // "KSyntaxHighlighting::Definition"
QT_MOC_LITERAL(3, 68, 0), // ""
QT_MOC_LITERAL(4, 69, 7), // "defName"
QT_MOC_LITERAL(5, 77, 21), // "definitionForFileName"
QT_MOC_LITERAL(6, 99, 8), // "fileName"
QT_MOC_LITERAL(7, 108, 22), // "definitionsForFileName"
QT_MOC_LITERAL(8, 131, 40), // "QVector<KSyntaxHighlighting::..."
QT_MOC_LITERAL(9, 172, 21), // "definitionForMimeType"
QT_MOC_LITERAL(10, 194, 8), // "mimeType"
QT_MOC_LITERAL(11, 203, 22), // "definitionsForMimeType"
QT_MOC_LITERAL(12, 226, 5), // "theme"
QT_MOC_LITERAL(13, 232, 26), // "KSyntaxHighlighting::Theme"
QT_MOC_LITERAL(14, 259, 9), // "themeName"
QT_MOC_LITERAL(15, 269, 12), // "defaultTheme"
QT_MOC_LITERAL(16, 282, 12), // "DefaultTheme"
QT_MOC_LITERAL(17, 295, 1), // "t"
QT_MOC_LITERAL(18, 297, 11), // "definitions"
QT_MOC_LITERAL(19, 309, 6), // "themes"
QT_MOC_LITERAL(20, 316, 35), // "QVector<KSyntaxHighlighting::..."
QT_MOC_LITERAL(21, 352, 10), // "LightTheme"
QT_MOC_LITERAL(22, 363, 9) // "DarkTheme"

    },
    "RepositoryWrapper\0definitionForName\0"
    "KSyntaxHighlighting::Definition\0\0"
    "defName\0definitionForFileName\0fileName\0"
    "definitionsForFileName\0"
    "QVector<KSyntaxHighlighting::Definition>\0"
    "definitionForMimeType\0mimeType\0"
    "definitionsForMimeType\0theme\0"
    "KSyntaxHighlighting::Theme\0themeName\0"
    "defaultTheme\0DefaultTheme\0t\0definitions\0"
    "themes\0QVector<KSyntaxHighlighting::Theme>\0"
    "LightTheme\0DarkTheme"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_RepositoryWrapper[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       2,   76, // properties
       1,   82, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // methods: name, argc, parameters, tag, flags
       1,    1,   54,    3, 0x02 /* Public */,
       5,    1,   57,    3, 0x02 /* Public */,
       7,    1,   60,    3, 0x02 /* Public */,
       9,    1,   63,    3, 0x02 /* Public */,
      11,    1,   66,    3, 0x02 /* Public */,
      12,    1,   69,    3, 0x02 /* Public */,
      15,    1,   72,    3, 0x02 /* Public */,
      15,    0,   75,    3, 0x22 /* Public | MethodCloned */,

 // methods: parameters
    0x80000000 | 2, QMetaType::QString,    4,
    0x80000000 | 2, QMetaType::QString,    6,
    0x80000000 | 8, QMetaType::QString,    6,
    0x80000000 | 2, QMetaType::QString,   10,
    0x80000000 | 8, QMetaType::QString,   10,
    0x80000000 | 13, QMetaType::QString,   14,
    0x80000000 | 13, 0x80000000 | 16,   17,
    0x80000000 | 13,

 // properties: name, type, flags
      18, 0x80000000 | 8, 0x00095409,
      19, 0x80000000 | 20, 0x00095409,

 // enums: name, alias, flags, count, data
      16,   16, 0x0,    2,   87,

 // enum data: key, value
      21, uint(RepositoryWrapper::LightTheme),
      22, uint(RepositoryWrapper::DarkTheme),

       0        // eod
};

void RepositoryWrapper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<RepositoryWrapper *>(_o);
        (void)_t;
        switch (_id) {
        case 0: { KSyntaxHighlighting::Definition _r = _t->definitionForName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KSyntaxHighlighting::Definition*>(_a[0]) = std::move(_r); }  break;
        case 1: { KSyntaxHighlighting::Definition _r = _t->definitionForFileName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KSyntaxHighlighting::Definition*>(_a[0]) = std::move(_r); }  break;
        case 2: { QVector<KSyntaxHighlighting::Definition> _r = _t->definitionsForFileName((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVector<KSyntaxHighlighting::Definition>*>(_a[0]) = std::move(_r); }  break;
        case 3: { KSyntaxHighlighting::Definition _r = _t->definitionForMimeType((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KSyntaxHighlighting::Definition*>(_a[0]) = std::move(_r); }  break;
        case 4: { QVector<KSyntaxHighlighting::Definition> _r = _t->definitionsForMimeType((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< QVector<KSyntaxHighlighting::Definition>*>(_a[0]) = std::move(_r); }  break;
        case 5: { KSyntaxHighlighting::Theme _r = _t->theme((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KSyntaxHighlighting::Theme*>(_a[0]) = std::move(_r); }  break;
        case 6: { KSyntaxHighlighting::Theme _r = _t->defaultTheme((*reinterpret_cast< DefaultTheme(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< KSyntaxHighlighting::Theme*>(_a[0]) = std::move(_r); }  break;
        case 7: { KSyntaxHighlighting::Theme _r = _t->defaultTheme();
            if (_a[0]) *reinterpret_cast< KSyntaxHighlighting::Theme*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<RepositoryWrapper *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QVector<KSyntaxHighlighting::Definition>*>(_v) = _t->definitions(); break;
        case 1: *reinterpret_cast< QVector<KSyntaxHighlighting::Theme>*>(_v) = _t->themes(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject RepositoryWrapper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_RepositoryWrapper.data,
    qt_meta_data_RepositoryWrapper,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *RepositoryWrapper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RepositoryWrapper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_RepositoryWrapper.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int RepositoryWrapper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 8;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
