/****************************************************************************
** Meta object code from reading C++ file 'theme.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.17)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../syntax-highlighting-5.116.0/src/lib/theme.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'theme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.17. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KSyntaxHighlighting__Theme_t {
    QByteArrayData data[64];
    char stringdata0[804];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KSyntaxHighlighting__Theme_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KSyntaxHighlighting__Theme_t qt_meta_stringdata_KSyntaxHighlighting__Theme = {
    {
QT_MOC_LITERAL(0, 0, 26), // "KSyntaxHighlighting::Theme"
QT_MOC_LITERAL(1, 27, 4), // "name"
QT_MOC_LITERAL(2, 32, 14), // "translatedName"
QT_MOC_LITERAL(3, 47, 9), // "TextStyle"
QT_MOC_LITERAL(4, 57, 6), // "Normal"
QT_MOC_LITERAL(5, 64, 7), // "Keyword"
QT_MOC_LITERAL(6, 72, 8), // "Function"
QT_MOC_LITERAL(7, 81, 8), // "Variable"
QT_MOC_LITERAL(8, 90, 11), // "ControlFlow"
QT_MOC_LITERAL(9, 102, 8), // "Operator"
QT_MOC_LITERAL(10, 111, 7), // "BuiltIn"
QT_MOC_LITERAL(11, 119, 9), // "Extension"
QT_MOC_LITERAL(12, 129, 12), // "Preprocessor"
QT_MOC_LITERAL(13, 142, 9), // "Attribute"
QT_MOC_LITERAL(14, 152, 4), // "Char"
QT_MOC_LITERAL(15, 157, 11), // "SpecialChar"
QT_MOC_LITERAL(16, 169, 6), // "String"
QT_MOC_LITERAL(17, 176, 14), // "VerbatimString"
QT_MOC_LITERAL(18, 191, 13), // "SpecialString"
QT_MOC_LITERAL(19, 205, 6), // "Import"
QT_MOC_LITERAL(20, 212, 8), // "DataType"
QT_MOC_LITERAL(21, 221, 6), // "DecVal"
QT_MOC_LITERAL(22, 228, 5), // "BaseN"
QT_MOC_LITERAL(23, 234, 5), // "Float"
QT_MOC_LITERAL(24, 240, 8), // "Constant"
QT_MOC_LITERAL(25, 249, 7), // "Comment"
QT_MOC_LITERAL(26, 257, 13), // "Documentation"
QT_MOC_LITERAL(27, 271, 10), // "Annotation"
QT_MOC_LITERAL(28, 282, 10), // "CommentVar"
QT_MOC_LITERAL(29, 293, 12), // "RegionMarker"
QT_MOC_LITERAL(30, 306, 11), // "Information"
QT_MOC_LITERAL(31, 318, 7), // "Warning"
QT_MOC_LITERAL(32, 326, 5), // "Alert"
QT_MOC_LITERAL(33, 332, 5), // "Error"
QT_MOC_LITERAL(34, 338, 6), // "Others"
QT_MOC_LITERAL(35, 345, 15), // "EditorColorRole"
QT_MOC_LITERAL(36, 361, 15), // "BackgroundColor"
QT_MOC_LITERAL(37, 377, 13), // "TextSelection"
QT_MOC_LITERAL(38, 391, 11), // "CurrentLine"
QT_MOC_LITERAL(39, 403, 15), // "SearchHighlight"
QT_MOC_LITERAL(40, 419, 16), // "ReplaceHighlight"
QT_MOC_LITERAL(41, 436, 15), // "BracketMatching"
QT_MOC_LITERAL(42, 452, 9), // "TabMarker"
QT_MOC_LITERAL(43, 462, 13), // "SpellChecking"
QT_MOC_LITERAL(44, 476, 15), // "IndentationLine"
QT_MOC_LITERAL(45, 492, 10), // "IconBorder"
QT_MOC_LITERAL(46, 503, 11), // "CodeFolding"
QT_MOC_LITERAL(47, 515, 11), // "LineNumbers"
QT_MOC_LITERAL(48, 527, 17), // "CurrentLineNumber"
QT_MOC_LITERAL(49, 545, 14), // "WordWrapMarker"
QT_MOC_LITERAL(50, 560, 13), // "ModifiedLines"
QT_MOC_LITERAL(51, 574, 10), // "SavedLines"
QT_MOC_LITERAL(52, 585, 9), // "Separator"
QT_MOC_LITERAL(53, 595, 12), // "MarkBookmark"
QT_MOC_LITERAL(54, 608, 20), // "MarkBreakpointActive"
QT_MOC_LITERAL(55, 629, 21), // "MarkBreakpointReached"
QT_MOC_LITERAL(56, 651, 22), // "MarkBreakpointDisabled"
QT_MOC_LITERAL(57, 674, 13), // "MarkExecution"
QT_MOC_LITERAL(58, 688, 11), // "MarkWarning"
QT_MOC_LITERAL(59, 700, 9), // "MarkError"
QT_MOC_LITERAL(60, 710, 18), // "TemplateBackground"
QT_MOC_LITERAL(61, 729, 19), // "TemplatePlaceholder"
QT_MOC_LITERAL(62, 749, 26), // "TemplateFocusedPlaceholder"
QT_MOC_LITERAL(63, 776, 27) // "TemplateReadOnlyPlaceholder"

    },
    "KSyntaxHighlighting::Theme\0name\0"
    "translatedName\0TextStyle\0Normal\0Keyword\0"
    "Function\0Variable\0ControlFlow\0Operator\0"
    "BuiltIn\0Extension\0Preprocessor\0Attribute\0"
    "Char\0SpecialChar\0String\0VerbatimString\0"
    "SpecialString\0Import\0DataType\0DecVal\0"
    "BaseN\0Float\0Constant\0Comment\0Documentation\0"
    "Annotation\0CommentVar\0RegionMarker\0"
    "Information\0Warning\0Alert\0Error\0Others\0"
    "EditorColorRole\0BackgroundColor\0"
    "TextSelection\0CurrentLine\0SearchHighlight\0"
    "ReplaceHighlight\0BracketMatching\0"
    "TabMarker\0SpellChecking\0IndentationLine\0"
    "IconBorder\0CodeFolding\0LineNumbers\0"
    "CurrentLineNumber\0WordWrapMarker\0"
    "ModifiedLines\0SavedLines\0Separator\0"
    "MarkBookmark\0MarkBreakpointActive\0"
    "MarkBreakpointReached\0MarkBreakpointDisabled\0"
    "MarkExecution\0MarkWarning\0MarkError\0"
    "TemplateBackground\0TemplatePlaceholder\0"
    "TemplateFocusedPlaceholder\0"
    "TemplateReadOnlyPlaceholder"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KSyntaxHighlighting__Theme[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       2,   14, // properties
       2,   20, // enums/sets
       0,    0, // constructors
       4,       // flags
       0,       // signalCount

 // properties: name, type, flags
       1, QMetaType::QString, 0x00095001,
       2, QMetaType::QString, 0x00095001,

 // enums: name, alias, flags, count, data
       3,    3, 0x0,   31,   30,
      35,   35, 0x0,   28,   92,

 // enum data: key, value
       4, uint(KSyntaxHighlighting::Theme::Normal),
       5, uint(KSyntaxHighlighting::Theme::Keyword),
       6, uint(KSyntaxHighlighting::Theme::Function),
       7, uint(KSyntaxHighlighting::Theme::Variable),
       8, uint(KSyntaxHighlighting::Theme::ControlFlow),
       9, uint(KSyntaxHighlighting::Theme::Operator),
      10, uint(KSyntaxHighlighting::Theme::BuiltIn),
      11, uint(KSyntaxHighlighting::Theme::Extension),
      12, uint(KSyntaxHighlighting::Theme::Preprocessor),
      13, uint(KSyntaxHighlighting::Theme::Attribute),
      14, uint(KSyntaxHighlighting::Theme::Char),
      15, uint(KSyntaxHighlighting::Theme::SpecialChar),
      16, uint(KSyntaxHighlighting::Theme::String),
      17, uint(KSyntaxHighlighting::Theme::VerbatimString),
      18, uint(KSyntaxHighlighting::Theme::SpecialString),
      19, uint(KSyntaxHighlighting::Theme::Import),
      20, uint(KSyntaxHighlighting::Theme::DataType),
      21, uint(KSyntaxHighlighting::Theme::DecVal),
      22, uint(KSyntaxHighlighting::Theme::BaseN),
      23, uint(KSyntaxHighlighting::Theme::Float),
      24, uint(KSyntaxHighlighting::Theme::Constant),
      25, uint(KSyntaxHighlighting::Theme::Comment),
      26, uint(KSyntaxHighlighting::Theme::Documentation),
      27, uint(KSyntaxHighlighting::Theme::Annotation),
      28, uint(KSyntaxHighlighting::Theme::CommentVar),
      29, uint(KSyntaxHighlighting::Theme::RegionMarker),
      30, uint(KSyntaxHighlighting::Theme::Information),
      31, uint(KSyntaxHighlighting::Theme::Warning),
      32, uint(KSyntaxHighlighting::Theme::Alert),
      33, uint(KSyntaxHighlighting::Theme::Error),
      34, uint(KSyntaxHighlighting::Theme::Others),
      36, uint(KSyntaxHighlighting::Theme::BackgroundColor),
      37, uint(KSyntaxHighlighting::Theme::TextSelection),
      38, uint(KSyntaxHighlighting::Theme::CurrentLine),
      39, uint(KSyntaxHighlighting::Theme::SearchHighlight),
      40, uint(KSyntaxHighlighting::Theme::ReplaceHighlight),
      41, uint(KSyntaxHighlighting::Theme::BracketMatching),
      42, uint(KSyntaxHighlighting::Theme::TabMarker),
      43, uint(KSyntaxHighlighting::Theme::SpellChecking),
      44, uint(KSyntaxHighlighting::Theme::IndentationLine),
      45, uint(KSyntaxHighlighting::Theme::IconBorder),
      46, uint(KSyntaxHighlighting::Theme::CodeFolding),
      47, uint(KSyntaxHighlighting::Theme::LineNumbers),
      48, uint(KSyntaxHighlighting::Theme::CurrentLineNumber),
      49, uint(KSyntaxHighlighting::Theme::WordWrapMarker),
      50, uint(KSyntaxHighlighting::Theme::ModifiedLines),
      51, uint(KSyntaxHighlighting::Theme::SavedLines),
      52, uint(KSyntaxHighlighting::Theme::Separator),
      53, uint(KSyntaxHighlighting::Theme::MarkBookmark),
      54, uint(KSyntaxHighlighting::Theme::MarkBreakpointActive),
      55, uint(KSyntaxHighlighting::Theme::MarkBreakpointReached),
      56, uint(KSyntaxHighlighting::Theme::MarkBreakpointDisabled),
      57, uint(KSyntaxHighlighting::Theme::MarkExecution),
      58, uint(KSyntaxHighlighting::Theme::MarkWarning),
      59, uint(KSyntaxHighlighting::Theme::MarkError),
      60, uint(KSyntaxHighlighting::Theme::TemplateBackground),
      61, uint(KSyntaxHighlighting::Theme::TemplatePlaceholder),
      62, uint(KSyntaxHighlighting::Theme::TemplateFocusedPlaceholder),
      63, uint(KSyntaxHighlighting::Theme::TemplateReadOnlyPlaceholder),

       0        // eod
};

void KSyntaxHighlighting::Theme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{

#ifndef QT_NO_PROPERTIES
    if (_c == QMetaObject::ReadProperty) {
        auto *_t = reinterpret_cast<Theme *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< QString*>(_v) = _t->name(); break;
        case 1: *reinterpret_cast< QString*>(_v) = _t->translatedName(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_o;
    (void)_id;
    (void)_c;
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject KSyntaxHighlighting::Theme::staticMetaObject = { {
    nullptr,
    qt_meta_stringdata_KSyntaxHighlighting__Theme.data,
    qt_meta_data_KSyntaxHighlighting__Theme,
    qt_static_metacall,
    nullptr,
    nullptr
} };

QT_WARNING_POP
QT_END_MOC_NAMESPACE
